@@ -1,7 +1,10 @@
+use std::{fs, io::Read, path::Path};
+
 use anyhow::{anyhow, Result};
+use quick_error::quick_error;
+
 use git_features::progress::{self, Progress};
 use git_odb::{loose, pack, Write};
-use std::{fs, io::Read, path::Path};
 
 #[derive(PartialEq, Debug)]
 pub enum SafetyCheck {
@@ -58,8 +61,6 @@ impl From<SafetyCheck> for pack::index::traverse::SafetyCheck {
     }
 }
 
-use quick_error::quick_error;
-
 quick_error! {
     #[derive(Debug)]
     enum Error {
@@ -77,7 +78,7 @@ quick_error! {
             display("Failed to write {} object {}", kind, id)
             source(&**err)
         }
-        Verify(err: loose::object::verify::Error) {
+        Verify(err: git_odb::data::verify::Error) {
             display("Object didn't verify after right after writing it")
             source(err)
             from()
@@ -88,7 +89,7 @@ quick_error! {
         WrittenFileMissing(id: git_hash::ObjectId) {
             display("The recently written file for loose object {} could not be found", id)
         }
-        WrittenFileCorrupt(err: loose::db::locate::Error, id: git_hash::ObjectId) {
+        WrittenFileCorrupt(err: loose::db::find::Error, id: git_hash::ObjectId) {
             display("The recently written file for loose object {} cold not be read", id)
             source(err)
         }
@@ -101,7 +102,7 @@ enum OutputWriter {
     Sink(git_odb::Sink),
 }
 
-impl git_odb::Write for OutputWriter {
+impl git_odb::write::Write for OutputWriter {
     type Error = Error;
 
     fn write_buf(
@@ -201,6 +202,7 @@ pub fn pack_or_pack_index(
                 } else {
                     None
                 };
+                let mut read_buf = Vec::new();
                 move |object_kind, buf, index_entry, progress| {
                     let written_id = out
                         .write_buf(object_kind, buf, git_hash::Kind::Sha1)
@@ -213,7 +215,7 @@ pub fn pack_or_pack_index(
                         }
                     }
                     if let Some(verifier) = object_verifier.as_ref() {
-                        let mut obj = verifier.locate(written_id)
+                        let obj = verifier.find(written_id, &mut read_buf)
                             .map_err(|err| Error::WrittenFileCorrupt(err, written_id))?
                             .ok_or(Error::WrittenFileMissing(written_id))?;
                         obj.verify_checksum(written_id)?;
@@ -222,7 +224,7 @@ pub fn pack_or_pack_index(
                 }
             }
         },
-        pack::cache::Lru::default,
+        pack::cache::lru::StaticLinkedList::<64>::default,
         pack::index::traverse::Options {
             algorithm,
             thread_limit,
