@@ -71,24 +71,23 @@ impl Default for Context<Vec<u8>, Vec<u8>> {
     }
 }
 
-#[allow(clippy::large_enum_variant)]
-enum EitherCache {
-    Left(pack::cache::Noop),
-    Right(pack::cache::Lru),
+enum EitherCache<const SIZE: usize> {
+    Left(pack::cache::Never),
+    Right(pack::cache::lru::StaticLinkedList<SIZE>),
 }
 
-impl pack::cache::DecodeEntry for EitherCache {
-    fn put(&mut self, offset: u64, data: &[u8], kind: Kind, compressed_size: usize) {
+impl<const SIZE: usize> pack::cache::DecodeEntry for EitherCache<SIZE> {
+    fn put(&mut self, pack_id: u32, offset: u64, data: &[u8], kind: Kind, compressed_size: usize) {
         match self {
-            EitherCache::Left(v) => v.put(offset, data, kind, compressed_size),
-            EitherCache::Right(v) => v.put(offset, data, kind, compressed_size),
+            EitherCache::Left(v) => v.put(pack_id, offset, data, kind, compressed_size),
+            EitherCache::Right(v) => v.put(pack_id, offset, data, kind, compressed_size),
         }
     }
 
-    fn get(&mut self, offset: u64, out: &mut Vec<u8>) -> Option<(Kind, usize)> {
+    fn get(&mut self, pack_id: u32, offset: u64, out: &mut Vec<u8>) -> Option<(Kind, usize)> {
         match self {
-            EitherCache::Left(v) => v.get(offset, out),
-            EitherCache::Right(v) => v.get(offset, out),
+            EitherCache::Left(v) => v.get(pack_id, offset, out),
+            EitherCache::Right(v) => v.get(pack_id, offset, out),
         }
     }
 }
@@ -137,12 +136,17 @@ where
                     e
                 })
                 .ok();
-            let cache = || -> EitherCache {
-                if output_statistics.is_some() {
-                    // turn off acceleration as we need to see entire chains all the time
-                    EitherCache::Left(pack::cache::Noop)
+            const CACHE_SIZE: usize = 64;
+            let cache = || -> EitherCache<CACHE_SIZE> {
+                if matches!(algorithm, Algorithm::LessMemory) {
+                    if output_statistics.is_some() {
+                        // turn off acceleration as we need to see entire chains all the time
+                        EitherCache::Left(pack::cache::Never)
+                    } else {
+                        EitherCache::Right(pack::cache::lru::StaticLinkedList::<CACHE_SIZE>::default())
+                    }
                 } else {
-                    EitherCache::Right(pack::cache::Lru::default())
+                    EitherCache::Left(pack::cache::Never)
                 }
             };
 
@@ -178,7 +182,7 @@ fn print_statistics(out: &mut impl io::Write, stats: &index::traverse::Outcome)
     }
     writeln!(out, "\t->: {}", total_object_count)?;
 
-    let pack::data::decode::Outcome {
+    let pack::data::decode_entry::Outcome {
         kind: _,
         num_deltas,
         decompressed_size,
